@@ -56,10 +56,6 @@ struct _GtkSourceEngineInterface
 
 	void     (* set_style_scheme) (GtkSourceEngine      *engine,
 				       GtkSourceStyleScheme *scheme);
-
-	GtkTextTag *(* get_context_class_tag)
-				      (GtkSourceEngine      *engine,
-				       const gchar          *context_class);
 };
 
 G_GNUC_INTERNAL
@@ -89,11 +85,6 @@ G_GNUC_INTERNAL
 void        _gtk_source_engine_set_style_scheme	(GtkSourceEngine      *engine,
 						 GtkSourceStyleScheme *scheme);
 
-G_GNUC_INTERNAL
-GtkTextTag *_gtk_source_engine_get_context_class_tag
-						 (GtkSourceEngine     *engine,
-						  const gchar         *context_class);
-
 G_END_DECLS
 
 #endif /* __GTK_SOURCE_ENGINE_H__ */
