@@ -22,6 +22,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcefileloader.h"
 #include "gtksourcebuffer.h"
 #include "gtksourcefile.h"
@@ -673,6 +677,9 @@ create_input_stream (GtkSourceFileLoader *loader)
 			case GTK_SOURCE_COMPRESSION_TYPE_NONE:
 				/* NOOP */
 				break;
+
+			default:
+				g_assert_not_reached ();
 		}
 	}
 
@@ -952,8 +959,8 @@ gtk_source_file_loader_get_file (GtkSourceFileLoader *loader)
  * gtk_source_file_loader_get_location:
  * @loader: a #GtkSourceFileLoader.
  *
- * Returns: (transfer none): the #GFile to load, or %NULL if an input stream is
- *   used.
+ * Returns: (nullable) (transfer none): the #GFile to load, or %NULL
+ * if an input stream is used.
  * Since: 3.14
  */
 GFile *
@@ -968,8 +975,8 @@ gtk_source_file_loader_get_location (GtkSourceFileLoader *loader)
  * gtk_source_file_loader_get_input_stream:
  * @loader: a #GtkSourceFileLoader.
  *
- * Returns: (transfer none): the #GInputStream to load, or %NULL if a #GFile is
- *   used.
+ * Returns: (nullable) (transfer none): the #GInputStream to load, or %NULL
+ * if a #GFile is used.
  * Since: 3.14
  */
 GInputStream *
