@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcegutterrenderertext.h"
 #include "gtksourceview-i18n.h"
 
@@ -78,17 +82,20 @@ gutter_renderer_text_begin (GtkSourceGutterRenderer *renderer,
 }
 
 static void
-center_on (GtkTextView  *view,
-           GdkRectangle *cell_area,
-           GtkTextIter  *iter,
-           gint          width,
-           gint          height,
-           gfloat        xalign,
-           gfloat        yalign,
-           gint         *x,
-           gint         *y)
+center_on (GtkSourceGutterRenderer *renderer,
+           GdkRectangle            *cell_area,
+           GtkTextIter             *iter,
+           gint                     width,
+           gint                     height,
+           gfloat                   xalign,
+           gfloat                   yalign,
+           gint                    *x,
+           gint                    *y)
 {
 	GdkRectangle location;
+	GtkTextView *view;
+
+	view = gtk_source_gutter_renderer_get_view (renderer);
 
 	gtk_text_view_get_iter_location (view, iter, &location);
 
@@ -106,7 +113,6 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			   GtkSourceGutterRendererState  state)
 {
 	GtkSourceGutterRendererText *text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
-	GtkTextView *view;
 	gint width;
 	gint height;
 	gfloat xalign;
@@ -114,6 +120,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 	GtkSourceGutterRendererAlignmentMode mode;
 	gint x = 0;
 	gint y = 0;
+	GtkTextView *view;
 	GtkStyleContext *context;
 
 	/* Chain up to draw background */
@@ -128,8 +135,6 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 												       state);
 	}
 
-	view = gtk_source_gutter_renderer_get_view (renderer);
-
 	if (text->priv->is_markup)
 	{
 		pango_layout_set_markup (text->priv->cached_layout,
@@ -149,15 +154,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 	                                          &xalign,
 	                                          &yalign);
 
-	/* Avoid calculations if we don't wrap text */
-	if (gtk_text_view_get_wrap_mode (view) == GTK_WRAP_NONE)
-	{
-		mode = GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_CELL;
-	}
-	else
-	{
-		mode = gtk_source_gutter_renderer_get_alignment_mode (renderer);
-	}
+	mode = gtk_source_gutter_renderer_get_alignment_mode (renderer);
 
 	switch (mode)
 	{
@@ -167,7 +164,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			break;
 
 		case GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_FIRST:
-			center_on (view,
+			center_on (renderer,
 			           cell_area,
 			           start,
 			           width,
@@ -179,7 +176,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			break;
 
 		case GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_LAST:
-			center_on (view,
+			center_on (renderer,
 			           cell_area,
 			           end,
 			           width,
@@ -194,6 +191,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			g_assert_not_reached ();
 	}
 
+	view = gtk_source_gutter_renderer_get_view (renderer);
 	context = gtk_widget_get_style_context (GTK_WIDGET (view));
 	gtk_render_layout (context, cr, x, y, text->priv->cached_layout);
 }
