@@ -4,19 +4,18 @@
  * Copyright (C) 2015 Christian Hergert <christian@hergert.me>
  * Copyright (C) 2015 Ignacio Casal Quinteiro <icq@gnome.org>
  *
- * GtkSourceView is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- * GtkSourceView is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GTK_SOURCE_MAP_H__
@@ -50,13 +49,17 @@ struct _GtkSourceMapClass
 	gpointer padding[10];
 };
 
-GType                    gtk_source_map_get_type	(void);
+GTK_SOURCE_AVAILABLE_IN_3_18
+GType			 gtk_source_map_get_type	(void);
 
+GTK_SOURCE_AVAILABLE_IN_3_18
 GtkWidget		*gtk_source_map_new		(void);
 
+GTK_SOURCE_AVAILABLE_IN_3_18
 void			 gtk_source_map_set_view	(GtkSourceMap  *map,
-                                                         GtkSourceView *view);
+							 GtkSourceView *view);
 
+GTK_SOURCE_AVAILABLE_IN_3_18
 GtkSourceView		*gtk_source_map_get_view	(GtkSourceMap  *map);
 
 G_END_DECLS
