@@ -19,12 +19,15 @@
  * along with GtkSourceView. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <glib/gi18n.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include "gtksourcestyleschemechooserbutton.h"
 #include "gtksourcestyleschemechooser.h"
 #include "gtksourcestyleschemechooserwidget.h"
 #include "gtksourcestylescheme.h"
+#include "gtksourceview-i18n.h"
 
 /**
  * SECTION:styleschemechooserbutton
